/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: AgentException Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: AgentException.h,v 1.2 2005/07/27 10:59:17 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_AGENTEXCEPTION_H_
#define GLITE_DATA_TRANSFER_AGENTS_AGENTEXCEPTION_H_

#include <exception>
#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
    
/**
 * Base class for all the Exception in File Transfer Agent
 */    
class AgentException : public std::exception{
public:
    /**
     * Constructor
     * @param reason [IN] the string containing the Exception reason
     */
    AgentException(const char * reason):m_reason(reason){}

    /**
     * Copy Constructor
     * @param other [IN] the object to be copied
     */
    AgentException(const AgentException& other):m_reason(other.m_reason){}

    /**
     * Destructor
     */
    virtual ~AgentException() throw(){}  

    /**
     * Retruns a string containing the reason nof the exception
     * @retrun a string containing the reason nof the exception
     */
    virtual const char * what() const throw() {return m_reason.c_str();}
protected:
    /**
     * Constructor
     */
    AgentException(){}  

    /**
     * Set Exception Reason
     * @param reason [IN] the string containing the Exception reason
     */
    void setReason(const char * reason){m_reason = reason;}
private:
    /**
     * Exception Reason Property
     */
    std::string m_reason;    
};

} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_AGENTEXCEPTION_H_
