/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: ActionFactory Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ActionFactoryMethod.h,v 1.4 2005/07/21 16:45:34 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_ACTION_ACTIONFACTORYMETHOD_H_
#define GLITE_DATA_TRANSFER_AGENTS_ACTION_ACTIONFACTORYMETHOD_H_

#include "glite/data/transfer/agent/action/ExecuteException.h"
#include "glite/data/transfer/agent/action/Action.h"
#include <map>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace action  {
    
/**
 * ActionFactoryMethod Class
 */
class ActionFactoryMethod {
public:
    
    /**
     * Destructor
     */
    virtual ~ActionFactoryMethod();

    /**
     * Create an instance of an action
     * @return the created instance
     * @throws ExecuteException in case of the Action type is not configured
     */
    virtual Action * create() /*throw (ExecuteException)*/ = 0; 

    /**
     * Return Action Type
     * @return the Action Type
     */
    const std::string& type() const{ return m_type;}
    
protected:
    
    /**
     * Constructor
     */
    ActionFactoryMethod(const std::string& type);

private:
    
    /**
     * Default Constructor Not Implemented
     */
    ActionFactoryMethod();
    
private:

    /**
     * Action Type
     */
    std::string m_type;

    /** @link dependency 
     * @label throws*/
    /*# ExecuteException lnkExecuteException; */

    /** @link dependency 
     * @label creates*/
    /*# Action lnkAction; */
};

#define DECLARE_FACTORY_METHOD( Class , Type) \
    private: \
    class ThisActionFactoryMethod : public ActionFactoryMethod { \
    public: \
        virtual Action * create() /*throw (ExecuteException)*/ { \
            return new Class(); \
        } \
    private: \
        friend class Class; \
        ThisActionFactoryMethod():ActionFactoryMethod(Type){} \
        static ThisActionFactoryMethod * s_instance; \
    }; \
    public: \
    static ActionFactoryMethod* factory(){return ThisActionFactoryMethod::s_instance;}
    
#define REGISTER_FACTORY_METHOD( Class ) \
    Class::ThisActionFactoryMethod* Class::ThisActionFactoryMethod::s_instance = \
        new Class::ThisActionFactoryMethod();

} // End namespace action
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_ACTION_ACTIONFACTORYMETHOD_H_
