/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: BasicRetry Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Retry.h,v 1.1 2005/10/26 16:22:51 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_RETRY_H_
#define GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_RETRY_H_

#include "glite/data/transfer/agent/action/vo/VOAction.h"
#include "glite/data/transfer/agent/action/vo/RetryStrategy.h"

#include <boost/scoped_ptr.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace action  {
namespace vo      {

/**
 * The purpose of that Action is to trigger the event to reschedule transfers
 * in Waiting State
 */
class Retry : public VOAction {
    
public:
    /**
     * Destructor
     */
    virtual ~Retry();

protected:
    /**
     * Constructor
     */
    Retry(const std::string& name, RetryStrategy * s);

    /**
     * Execute The Action
     */
    virtual void exec(const std::string& params,unsigned int& failures) /*throw (ExecuteException)*/;

private:

    /**
     * Trigger the rescheduling on a file
     */
    void processFile(const std::string& file_id, std::set<std::string>& ids) /*throw (ExecuteException)*/;

private:
    /**
     * Constructor. Not Implemented
     */
    Retry();

    /**
     * Copy Constructor. Not Implemented
     */
    Retry(const Retry&);

    /**
     * Assignment Operator. Not Implemented
     */
    Retry& operator=(const Retry&);

private:
    /**
     * The Strategy to use
     */
    boost::scoped_ptr<RetryStrategy> m_strategy;
};

} // End namespace vo
} // End namespace action
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_RETRY_H_
