/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: BasicRetry Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: RetryStrategy.h,v 1.1 2005/10/26 16:22:51 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_RETRYSTRATEGY_H_
#define GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_RETRYSTRATEGY_H_

#include "glite/data/transfer/agent/model/Job.h"
#include "glite/data/transfer/agent/model/File.h"
#include "glite/data/transfer/agent/model/Transfer.h"
#include "glite/data/transfer/agent/model/Error.h"

#include <vector>
#include <boost/shared_ptr.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace action  {
namespace vo      {

/**
 * The purpose of that Strategy is to define if a File has to be retried, failed 
 * or has to stay in Pending
 */
class RetryStrategy {
public:

    typedef std::vector<boost::shared_ptr<const model::Transfer> > TransferArray;

    /**
     * RetryResult Type
     */
    typedef enum{
        UNDEF   = 0,
        WAIT       ,
        RETRY      ,
        HOLD       ,
        FAIL
    } RetryResult;

    /**
     * Destructor
     */
    virtual ~RetryStrategy(){}

    /**
     * Execute The Action
     */
    virtual RetryResult apply(const model::Job& job,const model::File& file, const TransferArray& transfers) /*throw (ExecuteException)*/ = 0;

protected:
    /**
     * Constructor
     */
    RetryStrategy(){}

private:
    /**
     * Copy Constructor. Not Implemented
     */
    RetryStrategy(const RetryStrategy&);

    /**
     * Assignment Operator. Not Implemented
     */
    RetryStrategy& operator=(const RetryStrategy&);
};

} // End namespace vo
} // End namespace action
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_RETRYSTRATEGY_H_
