/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: CatalogServiceException Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: CatalogServiceException.h,v 1.2 2005/07/27 10:59:17 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_CATALOG_CATALOGSERVICEEXCEPTION_H_
#define GLITE_DATA_TRANSFER_AGENTS_CATALOG_CATALOGSERVICEEXCEPTION_H_

#include "glite/data/transfer/agent/AgentException.h"
#include <vector>
#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace catalog {
    
/**
 * The Exception is thrown when an error happens on CatalogService
 */
class CatalogServiceException : public AgentException {
public:

    typedef std::pair<std::string,std::string> StringPair;
    typedef std::vector<std::string>           StringArray;
    typedef std::vector<StringPair>            StringPairArray;
    
    /**
     * Constructor
     * @param reason [IN] the reason of the error
     */
    CatalogServiceException(const char * reason):AgentException(reason){}

    /**
     * Copy Constructor
     * @param reason [IN] the reason of the error
     */
    CatalogServiceException(const CatalogServiceException& other):AgentException(other){
        m_failed.insert(m_failed.begin(),other.m_failed.begin(),other.m_failed.end());
    }

    /**
     * Get the list of logical names that are failed with the related error
     * @return a reference to the list of logical names that are failed with the 
     *  related error
     */
    virtual const StringPairArray& getFailed() const {return m_failed;}

    /**
     * Destructor
     */
    virtual ~CatalogServiceException() throw() {}
    
private:

    /**
     * Default Constructor Not Implemented
     */
    CatalogServiceException();

protected:
    /**
     * The list of logical names that are failed
     */
    StringPairArray m_failed;
};

} // end namespace catalog
} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_CATALOG_CATALOGSERVICEEXCEPTION_H_
