/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: CertProxyService Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: CertProxyService.h,v 1.2 2005/07/21 16:45:34 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_CERTPROXY_CERTPROXYSERVICE_H_
#define GLITE_DATA_TRANSFER_AGENTS_CERTPROXY_CERTPROXYSERVICE_H_

#include "glite/data/transfer/agent/certproxy/CertProxyServiceException.h"

namespace glite    {
namespace data     {
namespace transfer {
namespace agent    {
namespace certproxy{

/**
 * CertProxyService Interface.
 * Define the interface for retrieving a proxy certiticate for a given user DN
 */
class CertProxyService{
public:

    /**
     * Destructor
     */
    virtual ~CertProxyService(){}
        
    /**
     * Get The proxy certificate for the requested user
     * @param userDn [IN] The Distinguished name of the user
     * @param passphrase [IN] The Passphrase needed to retrieve the proxy 
     *        certificate
     * @param filename [OUT] the name of the file where the proxy certificate
     *        will be stored
     * @throws CertProxyServiceException in case of errors
     */
    virtual void get(const std::string& userDn, 
                     const std::string& passphrase, 
                           std::string& filename) /*throw (CertProxyServiceException)*/ = 0;
protected:
    /**
     * Constructor
     */
    CertProxyService(){}

private:
    /** @link dependency 
     * @label throws*/
    /*# CertProxyServiceException lnkCertProxyServiceException; */
};

} // end namespace certproxy
} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_CERTPROXY_CERTPROXYSERVICE_H_
