/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: CertProxyServiceFactory Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: CertProxyServiceFactory.h,v 1.2 2005/09/26 14:14:00 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_CERTPROXY_CERTPROXYSERVICEFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_CERTPROXY_CERTPROXYSERVICEFACTORY_H_

#include "glite/data/transfer/agent/certproxy/CertProxyServiceException.h"
#include "glite/data/transfer/agent/certproxy/CertProxyService.h"

namespace glite    {
namespace data     {
namespace transfer {
namespace agent    {
namespace certproxy{

/**
 * CertProxyServiceFactory interface
 * @interface
 */
class CertProxyServiceFactory  {
public:

    /**
     * Return Job Param Tag. If a user wants to specify teh certproxy server to 
     * use, he would have to endcode it's endpoint in the job parameters using 
     * the option "<tag> <endpoint>" where <tag> shold be the value returned 
     * by this function. It's a good practice to start <tag> with two dashes
     * @return the tag to be used to search the server in the job params
     * @throws CertProxyServiceException in case of error
     */
    virtual std::string getTag() /*throw ()*/ = 0; 

    /**
     * Return the CertProxy Service Type to be used to query ServiceDiscovery.
     * @return the CertProxy Service Type to be used to query ServiceDiscovery 
     */
    virtual std::string getServiceType() /*throw ()*/ = 0;

    /**
     * Create a CertProxyService instance
     * @param endpoint [IN] the service hostname and port to contact. If this 
     * parameter is empty, ServiceDiscovery will be used to find the endpoint 
     * of the Server to contact, first looking at the associted services of 
     * the FTS service specified using the setAssociatedService method; if not 
     * found, it would take the first value returned by SevriceDiscovery.
     * @return a new instance of a CertProxyService
     * @throws CertProxyServiceException in case of error
     */
    virtual CertProxyService * create(const std::string& endpoint) /*throw (CertProxyServiceException)*/ = 0; 

    /**
     * Return the configured CertProxyServiceFactory Instance. Please note that 
     * this method doesn't allocate the instance (it's not a singleton)
     * @return the configued CertProxyServiceFactory 
     * @throws CertProxyServiceException in case of no CertProxyServiceFactory is
     * configured
     */
    static CertProxyServiceFactory * getInstance() /*throw (CertProxyServiceException)*/; 
   
protected:

    /**
     * Constructor
     */ 
    CertProxyServiceFactory();

    /**
     * Destructor
     */ 
    virtual ~CertProxyServiceFactory();

private:

    /**
     * The registered Instance
     */
    static CertProxyServiceFactory * s_instance;
    
    /** @link dependency 
     * @label creates*/
    /*# CertProxyService lnkCertProxyService; */

    /** @link dependency 
     * @label throws*/
    /*# CertProxyServiceException lnkCertProxyServiceException; */
};

} // end namespace certproxy
} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_CERTPROXY_CERTPROXYSERVICEFACTORY_H_
