/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: AgentDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: AgentDAO.h,v 1.1 2005/08/04 09:44:18 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_AGENTDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_AGENTDAO_H_

#include "glite/data/transfer/agent/model/Agent.h"
#include "glite/data/transfer/agent/dao/DAOException.h"

#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {

/**
 * Data Access Object For the model::Agent class
 * @interface
 */
class AgentDAO {
public:
    /**
     * Destructor
     */
    virtual ~AgentDAO(){}
        
    /**
     * Return the Channel with the given Name
     */
    virtual model::Agent * get(bool lock = false) /*throw (DAOException)*/ = 0;

    /**
     * Update a Agent object
     */
    virtual void update(const model::Agent& obj) = 0; // throw (DAOException)

    /**
     * Insert a new Agent instance
     */
    virtual void create(const model::Agent& obj) = 0; // throw (DAOException)

private:

    /** @link dependency 
     * @label creates/updates*/
    /*# model::Agent lnkAgent; */

    /** @link dependency 
     * @label throws*/
    /*# DAOException lnkDAOException; */
};

} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_AGENTDAO_H_
