/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: ChannelDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ChannelDAO.h,v 1.5 2005/08/04 09:44:18 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNELDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNELDAO_H_

#include "glite/data/transfer/agent/model/Channel.h"
#include "glite/data/transfer/agent/dao/DAOException.h"

#include <string>
#include <set>
#include <vector>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {

/**
 * Data Access Object For the model::Channel class
 * @interface
 */
class ChannelDAO {
public:
    /**
     * StringArray Type
     */
    typedef std::vector<std::string> StringArray;

    /**
     * Destructor
     */
    virtual ~ChannelDAO(){}
        
    /**
     * Return the Channel with the given Name
     */
    virtual model::Channel * get(const std::string& name, bool lock = false) /*throw (DAOException)*/ = 0;

    /**
     * Update a Channel object
     */
    virtual void update(const model::Channel& obj) = 0; // throw (DAOException)

private:

    /** @link dependency 
     * @label creates/updates*/
    /*# model::Channel lnkChannel; */

    /** @link dependency 
     * @label throws*/
    /*# DAOException lnkDAOException; */
};

} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNELDAO_H_
