/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: DAOContext Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: DAOContext.h,v 1.3 2006/01/30 15:19:34 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_DAOCONTEXT_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_DAOCONTEXT_H_

#include "glite/data/transfer/agent/dao/DAOException.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {

/**
 * Base Class For DataAccessObject Context
 * @interface
 */
class DAOContext {
public:

    /**
     * Destructor
     */ 
    virtual ~DAOContext(){}
        
    /**
     * Check if the Context is valid alive
     */
    virtual void check() /*throw (DAOException)*/ = 0;

    /**
     * Start a Transaction
     */
    virtual void start() /*throw (DAOException)*/ = 0;

    /**
     * Commit a Transaction
     */
    virtual void commit() /*throw (DAOException)*/ = 0;

    /**
     * Rollback a Transaction
     */
    virtual void rollback() /*throw ()*/ = 0;
    
    /**
     * Kill the connection asynchronously
     */
    virtual void kill() /*throw ()*/ = 0;

protected:

    /**
     * Constructor
     */ 
    DAOContext(){}

private:

    /** @link dependency 
     * @label throws*/
    /*# DAOException lnkDAOException; */
};

} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_DAOCONTEXT_H_
