/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: JobDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: JobDAO.h,v 1.8 2005/06/30 16:36:17 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_JOBDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_JOBDAO_H_

#include "glite/data/transfer/agent/model/Job.h"
#include "glite/data/transfer/agent/dao/DAOException.h"

#include <string>
#include <vector>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {

/**
 * Data Access Object For the model::Job class
 * @interface
 */
class JobDAO {
public:
    /**
     * StringArray Type
     */
    typedef std::vector<std::string> StringArray;

    /**
     * Destructor
     */
    virtual ~JobDAO(){}
        
    /**
     * Return the Job with the given id
     */
    virtual model::Job * get(const std::string& id, bool lock = false) /*throw (DAOException)*/ = 0;

    /**
     * Update a Job object
     */
    virtual void update(const model::Job& obj) /*throw (DAOException)*/ = 0;

    /**
     * Update the state of all the transfer jobs in the given array
     * Note: Probably this shoudn't be a DAO method, but I assume that it could 
     * be implemented using features like Triggers or Stored Procedures 
     * available on some Data Sources
     */
    virtual void updateStates(const StringArray& ids, bool enableFinalStates, bool lock = false) /*throw (DAOException)*/ = 0;

    /**
     * Update the state of all the jobs.
     * the behavior of this method is the same of the previous one when the list 
     * of provided ids is empty
     */
    virtual void updateStates(bool enableFinalStates, bool lock = true) /*throw (DAOException)*/ = 0;

private:

    /** @link dependency 
     * @label creates/updates*/
    /*# glite::data::transfer::agent::model::Job lnkJob; */

    /** @link dependency 
     * @label throws*/
    /*# DAOException lnkDAOException; */
};

} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_JOBDAO_H_
