/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: TransferDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: TransferDAO.h,v 1.3 2005/11/10 16:04:06 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_TRANSFERDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_TRANSFERDAO_H_

#include "glite/data/transfer/agent/model/Transfer.h"
#include "glite/data/transfer/agent/dao/DAOException.h"

#include <string>
#include <vector>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {

/**
 * Data Access Object For the model::Transfer class
 * @interface
 */
class TransferDAO {
public:
    /**
     * StringArray Type
     */
    typedef std::vector<std::string> StringArray;

    /**
     * Destructor
     */
    virtual ~TransferDAO(){}

    /**
     * Return the Transfer with the given FileId - RequestId
     */
    virtual model::Transfer * get(const std::string& file_id, const std::string& req_id, bool lock = false) /*throw (DAOException)*/ = 0;

    /**
     * Update a File instance
     */
    virtual void update(const model::Transfer& obj) /*throw (DAOException)*/ = 0;

    /**
     * Return the list of Transfer instances for the given File Id, ordered by 
     * transfer time descending
     */
    virtual void getByFileId(const std::string& file_id, StringArray& ids, unsigned long limit = 0, bool lock = false) /*throw (DAOException)*/ = 0;

    /**
     * Return the list of Transfer instances for the given Request Id
     */
    virtual void getByRequestId(const std::string& request_id, StringArray& ids, bool lock = false) /*throw (DAOException)*/ = 0;

private:

    /** @link dependency 
     * @label creates/updates*/
    /*# glite::data::transfer::agent::model::Transfer lnkTransfer; */

    /** @link dependency 
     * @label throws*/
    /*# DAOException lnkDAOException; */
};

} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_TRANSFERDAO_H_
