/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: ChannelViewChannelDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ChannelDAO.h,v 1.6 2005/09/20 14:17:29 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_CHANNELDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_CHANNELDAO_H_

#include "glite/data/transfer/agent/model/Channel.h"
#include "glite/data/transfer/agent/dao/DAOException.h"
#include "glite/data/transfer/agent/dao/ChannelDAO.h"

#include <string>
#include <set>
#include <vector>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace channel {

/**
 * Data Access Object For the model::Channel class
 * @interface
 */
class ChannelDAO : public glite::data::transfer::agent::dao::ChannelDAO {
public:
    /**
     * Destructor
     */
    virtual ~ChannelDAO(){}
        
    /**
     * Update a Channel Last Active Property
     */
    virtual void updateLastActive(const model::Channel& obj) = 0; // throw (DAOException)

    /**
     * Return the list of VO that are allowed to submit request to the Channel
     * @param vo_names [OUT] the list where to store the returned VO names
     * @param limit  [IN] the maximum number of entries that can be returned
     * @param offset [IN] the starting offset
     * @throws DAOException in case of error
     */
    virtual void getVONames(StringArray& vo_names, unsigned int limit = 0, unsigned int offset = 0) /*throw (DAOException)*/ = 0;
        
    /**
     * Return the configured share (as percentage) for the given VO on 
     * the channel. The normalization of that value can be changed using the
     * parameters 'normalized' and 'only_vo_with_active_jobs'. Supposing a 
     * channel has 2 VOs with the following shares<br>
     *  VO_1: 20 <br>
     *  VO_2: 50 (with currently no active jobs)<br>
     * the values returned would be <br>
     * <table><tr>
     * <td> normalized </td><td> o.v.w.a.j </td><td> VO_1 </td><td> VO_2 </td>
     * <td> false      </td><td> false     </td><td> 0.2 </td><td> 0.5 </td>
     * <td> true       </td><td> false     </td><td> 2/7 </td><td> 5/7</td>
     * <td> false      </td><td> true      </td><td> 0.2 </td><td> 0.0 </td>
     * <td> true       </td><td> true      </td><td> 1.0 </td><td> 0.0 </td>
     * </tr></table>
     * @param vo_name [IN] the name of the requested vo
     * @param normalized [IN] If this value is set to true, the returned value 
     *  is normalized to the sum of all the vo shares on the channel
     * @param only_vo_with_active_jobs [IN] when normalizing, consider just the 
     *  VOs whit active jobs (state in Pending or Active). This means 
     *  that if the 'nomalized' flag is set to true, the value taken for 
     *  normalization is instead the sum of the share for the VO with active 
     *  jobs
     * @throws DAOException in case of error
     */
    virtual double getShare(const std::string& vo_name, bool normalized = false, bool only_vo_with_active_jobs = false) /*throw (DAOException)*/ = 0;
};

} // End namespace channel
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_CHANNELDAO_H_
