/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: ChannelViewDAOFactory Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: DAOFactory.h,v 1.4 2005/08/04 09:44:18 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_DAOFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_DAOFACTORY_H_

#include "glite/data/transfer/agent/dao/channel/FileDAO.h"
#include "glite/data/transfer/agent/dao/channel/JobDAO.h"
#include "glite/data/transfer/agent/dao/channel/TransferDAO.h"
#include "glite/data/transfer/agent/dao/channel/ChannelDAO.h"
#include "glite/data/transfer/agent/dao/channel/AgentDAO.h"
#include "glite/data/transfer/agent/dao/DAOFactory.h"
#include "glite/data/transfer/agent/dao/DAOException.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace channel {

/**
 * Base Class For creating the DataAccessObject ChannelView instances
 * @interface
 */
class DAOFactory : public glite::data::transfer::agent::dao::DAOFactory {
public:

    /**
     * Returns DataAccessObject for model:File instances
     * @param channel_name [IN] The name of the channel to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual FileDAO * createFileDAO(const std::string& channel_name, DAOContext& ctx) /*throw (DAOException)*/ = 0;

    /**
     * Returns DataAccessObject for model:Job instances
     * @param channel_name [IN] The name of the channel to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual JobDAO * createJobDAO(const std::string& channel_name, DAOContext& ctx) /*throw (DAOException)*/ = 0;

    /**
     * Returns DataAccessObject for model:Transfer instances
     * @param channel_name [IN] The name of the channel to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual TransferDAO * createTransferDAO(const std::string& channel_name, DAOContext& ctx) /*throw (DAOException)*/ = 0;

    /**
     * Returns DataAccessObject for model:Channel instances
     * @param channel_name [IN] The name of the channel to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual ChannelDAO * createChannelDAO(const std::string& channel_name, DAOContext& ctx) /*throw (DAOException)*/ = 0;

    /**
     * Returns DataAccessObject for model:Agent instances
     * @param channel_name [IN] The name of the channel to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual AgentDAO * createAgentDAO(const std::string& channel_name, DAOContext& ctx) /*throw (DAOException)*/ = 0;

    /**
     * Return the configured DAOFactory Instance. Please note that 
     * this method doesn't allocate the instance (Isn not a singleton)
     * @return the configured DAOFactory 
     * @throws DAOException in case of no DAOFactory is configured
     */
    static DAOFactory * getInstance() /*throw (DAOException)*/;

protected:

    /**
     * Constructor
     */ 
    DAOFactory();

    /**
     * Destructor
     */ 
    virtual ~DAOFactory();

private:

    /**
     * The registered Instance
     */
    static DAOFactory * s_instance;
    
    /** @link dependency 
     * @label creates*/
    /*# FileDAO lnkFileDAO; */

    /** @link dependency 
     * @label creates*/
    /*# JobDAO lnkJobDAO; */

    /** @link dependency
     * @label creates*/
    /*# TransferDAO lnkTransferDAO; */

    /** @link dependency
     * @label creates*/
    /*# ChannelDAO lnkChannelDAO; */

    /** @link dependency 
     * @label throws*/
    /*# DAOException lnkDAOException; */
};

} // End namespace channel
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_DAOFACTORY_H_
