/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: FileDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: FileDAO.h,v 1.5 2005/07/25 14:41:22 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_FILEDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_FILEDAO_H_

#include "glite/data/transfer/agent/model/File.h"
#include "glite/data/transfer/agent/dao/DAOException.h"
#include "glite/data/transfer/agent/dao/FileDAO.h"
#include "glite/data/transfer/agent/dao/StringArrayTable.h"

#include <string>
#include <vector>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace channel {

/**
 * Data Access Object For the model::File class filtered with a Channel View
 * @interface
 */
class FileDAO : public glite::data::transfer::agent::dao::FileDAO {
public:

    typedef  StringArrayTable FilesPerJobList;
    
    /**
     * Destructor
     */
    virtual ~FileDAO(){}

    /**
     * Return the next job (and file Ids) files to transfer for the given 
     * channel following the rule: files in pending or waiting state, which job 
     * state is pending, order by job_priority, job submission time, job_id for 
     * the given VO
     */
    virtual void getNextJobToTransfer(const std::string& vo_name, std::string& job_id, std::vector<std::string>& file_ids, bool lock = false, unsigned int limit = 0) /*throw (DAOException)*/ = 0;
};

} // End namespace channel
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_FILEDAO_H_
