/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: VOViewChannelDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ChannelDAO.h,v 1.4 2005/09/12 17:21:46 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_VO_CHANNELDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_VO_CHANNELDAO_H_

#include "glite/data/transfer/agent/model/Channel.h"
#include "glite/data/transfer/agent/dao/DAOException.h"
#include "glite/data/transfer/agent/dao/ChannelDAO.h"

#include <string>
#include <set>
#include <vector>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace vo      {

/**
 * Data Access Object For the model::Channel filtered on VOView
 * @interface
 */
class ChannelDAO : public glite::data::transfer::agent::dao::ChannelDAO {
public:

    /**
     * Destructor
     */
    virtual ~ChannelDAO(){}
     
    /**
     * Return the name of the Channel based on the sites' endpoint and channel 
     * share. In case no channel could be found, returns and empty string
     */
    virtual std::string getBySites(const std::string& ssite, const std::string& dsite) /*throw (DAOException)*/ = 0;
        
    /**
     * Returns true if the VO has a share for the given channel, false otherwise
     * @param channel_name [IN] the name of the requested channel
     * @return true if the VO has a share for the given channel, false otherwise
     * @throws DAOException in case of error
     */
    virtual bool hasShare(const std::string& channel_name) /*throw (DAOException)*/ = 0;
};

} // End namespace vo
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_VO_CHANNELDAO_H_
