/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: FileDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: FileDAO.h,v 1.8 2005/07/25 14:41:22 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_VO_FILEDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_VO_FILEDAO_H_

#include "glite/data/transfer/agent/model/File.h"
#include "glite/data/transfer/agent/dao/DAOException.h"
#include "glite/data/transfer/agent/dao/FileDAO.h"
#include "glite/data/transfer/agent/dao/StringArrayTable.h"

#include <string>
#include <vector>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace vo      {

/**
 * Data Access Object For the model::File class, filtered with a VO View
 * @interface
 */
class FileDAO : public glite::data::transfer::agent::dao::FileDAO{
public:
    typedef  StringArrayTable FilesPerJobList;
    
    /**
     * Destructor
     */
    virtual ~FileDAO(){}
        
    /**
     * Return the list of identifiers of the file which state is WAITING and 
     * the related job state is ACTIVE
     * @param fileIds [OUT] The array that will hold the File Ids
     * @param lock    [IN]  Lock the concerned rows
     * @param limit   [IN]  The upper row bound of the query
     * @param offset  [IN]  The lower row bound of the query
     */
    virtual void getWaitingFiles(StringArray& fileIds, bool lock = false, unsigned int limit = 0, unsigned int offset = 0) /*throw (DAOException)*/ = 0;

    /**
     * Return the list of identifiers of the file which state is SUBMITTED,
     * PENDING, WAITING or HOLD and the related job state is CANCELING.
     * @param fileIds [OUT] The array that will hold the File Ids
     * @param lock    [IN]  Lock the concerned rows
     * @param limit   [IN]  The upper row bound of the query
     * @param offset  [IN]  The lower row bound of the query
     */
    virtual void getFilesToCancel(StringArray& fileIds, bool lock = false, unsigned int limit = 0, unsigned int offset = 0) /*throw (DAOException)*/ = 0;

    /**
     * Return the list of files to be registered on tha catalog following 
     * the rule: files in done state, with a non empty LFN and with a job state 
     * Done, Failed or Canceled
     * order by job_priority, job submission time, job_id for the given VO. 
     * @param job_id  [OUT] The id of the job to register
     * @param file_ids[OUT] The array that will hold the File Ids
     * @param lock    [IN]  Lock the concerned rows
     */
    virtual void getJobToRegister(std::string& job_id, std::vector<std::string>& file_ids, bool lock = false) /*throw (DAOException)*/ = 0;
};

} // End namespace vo
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_VO_FILEDAO_H_
