/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: Agent Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Agent.h,v 1.3 2005/10/20 13:56:05 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_MODEL_AGENT_H_
#define GLITE_DATA_TRANSFER_AGENTS_MODEL_AGENT_H_

#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace model   {

/**
 * Agent Class
 * @stereotype ValueObject
 */
struct Agent {

    typedef enum{ // Define values so they could combined in OR
        S_UNDEF        = 0x0000,
        S_STARTED      = 0x0001,
        S_STOPPED      = S_STARTED    << 1  //0x0002
    } State;

    /**
     * Default Constructor
     */
    Agent():state(S_UNDEF),lastActive((time_t)-1){}

    /**
     * Constructor
     */
    Agent(const std::string& t,         // agent_type
                State        s,         // agent_state
          const std::string& v,         // agent_version
          const std::string& host,      // agent_host
          const std::string& c = "",    // contact
                time_t l = (time_t)-1): // last_active
            state(s),type(t),version(v),
            hostName(host),contact(c),lastActive(l){}

    /**
     * State Property
     */
    State state;

    /**
     * Type Property
     */
    std::string type;

    /**
     * Version Property
     */
    std::string version;

    /**
     * HostName Property
     */
    std::string hostName;

    /**
     * Contact Property
     */
    std::string contact;

    /**
     * LastActive Property
     */
    time_t lastActive;
};

} // End namespace model
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_MODEL_AGENT_H_
