/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: Channel Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Channel.h,v 1.3 2005/10/20 13:56:05 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_MODEL_CHANNEL_H_
#define GLITE_DATA_TRANSFER_AGENTS_MODEL_CHANNEL_H_

#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace model   {

/**
 * Channel Class
 * @stereotype ValueObject
 */
struct Channel {

    typedef enum{ // Define values so they could combined in OR
        S_UNDEF        = 0x0000,
        S_ACTIVE       = 0x0001,
        S_DRAIN        = S_ACTIVE     << 1,  //0x0002
        S_INACTIVE     = S_DRAIN      << 1,  //0x0004
        S_STOPPED      = S_INACTIVE   << 1,  //0x0008
        S_HALTED       = S_STOPPED    << 1   //0x0010
    } State;

    /**
     * Default Constructor
     */
    Channel():state(S_UNDEF),files(0),streams(0),bandwidth(0.0),
            throughput(0.0),lastActive((time_t)-1){}

    /**
     * Constructor
     */
    Channel(const std::string& n,         // channel_name
                  State        s,         // channel_state
            const std::string& ssite,     // source_site
            const std::string& dsite,     // dest_site
                  unsigned int files,     // num_of_files
                  unsigned int strms = 0, // num_of_streams
                  double       b = 0,     // bandwidth
                  double       t = 0,     // nominal_throughput
            const std::string& c = "",    // contact
                  time_t l = (time_t)-1): // last_active
            name(n),state(s),sourceSite(ssite),destSite(dsite),
            files(files),streams(strms),bandwidth(b),throughput(t),
            contact(c),lastActive(l){}

    /**
     * Name Property
     */
    std::string const name;

    /**
     * State Property
     */
    State state;

    /**
     * SourceSite Property
     */
    std::string const sourceSite;

    /**
     * DestSite Property
     */
    std::string const destSite;

    /**
     * Number of Files Property
     */
    unsigned int const files;
        
    /**
     * Number of Streams Property
     */
    unsigned int const streams;
        
    /**
     * Bandwidth Property
     */
    double const bandwidth;
        
    /**
     * Nominal Throughput Property
     */
    double const throughput;
    
    /**
     * Contact Property
     */
    std::string const contact;
    
    /**
     * LastActive Property
     */
    time_t lastActive;
};

} // End namespace model
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_MODEL_CHANNEL_H_
