/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: File Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: File.h,v 1.6 2005/11/09 17:37:39 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_MODEL_FILE_H_
#define GLITE_DATA_TRANSFER_AGENTS_MODEL_FILE_H_

#include "glite/data/transfer/agent/glite-types.h"
#include "glite/data/transfer/agent/model/Error.h"
#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace model   {
    
/**
 * File Class
 * @stereotype ValueObject
 */
struct File {

    typedef enum{ // Define values so they could combined in OR
        S_UNDEF           = 0x0000,
        S_SUBMITTED       = 0x0001,
        S_PENDING         = S_SUBMITTED       << 1,  //0x0002
        S_ACTIVE          = S_PENDING         << 1,  //0x0004
        S_WAITING         = S_ACTIVE          << 1,  //0x0008
        S_HOLD            = S_WAITING         << 1,  //0x0010
        S_CANCELING       = S_HOLD            << 1,  //0x0020
        S_DONE            = S_CANCELING       << 1,  //0x0040
        S_CANCELED        = S_DONE            << 1,  //0x0080
        S_FAILED          = S_CANCELED        << 1,  //0x0100
        S_CATALOG_FAILED  = S_FAILED          << 1,  //0x0200
        S_FINISHED        = S_CATALOG_FAILED  << 1,  //0x0400
    } State;

    /**
     * Default Constructor
     */
    File():state(S_UNDEF),reasonClass(Error::UNDEF),fileSize(-1),
           failures(0),currentFailures(0),finishTime((time_t)-1){}

    /**
     * Constructor
     */
    File(const std::string& i,                    // file_id
         const std::string& j_id,                 // job_id
               State        s,                    // file_state
         const std::string& l     = "",           // logical_name
         const std::string& ssurl = "",           // source_surl
         const std::string& dsurl = "",           // dest_surl
               Error::Category rc = Error::UNDEF, // reason_class
         const std::string& r     = "",           // reason
               unsigned int fl    = 0,            // failures
               unsigned int cf    = 0,            // current_failures
               longlong fs        = -1,           // filesize
         const std::string& cksum = "",           // check_sum
               time_t       ft    = (time_t)-1,   // finish_time
         const std::string& dn    = ""):          // agent_dn
                 id(i),jobId(j_id),state(s),logical(l),
                 sourceSurl(ssurl),destSurl(dsurl),reasonClass(rc),
                 reason(r),failures(fl),currentFailures(cf),fileSize(fs),
                 checksum(cksum),finishTime(ft),agentDn(dn){}

    /**
     * Id Property
     */
    std::string const id;

    /**
     * Job Id Property
     */
    std::string const jobId;

    /**
     * State Property
     */
    State state;

    /**
     * Logical Name Property
     */
    std::string const logical;

    /**
     * Source SURL Property
     */
    std::string sourceSurl;

    /**
     * Dest SURL Property
     */
    std::string destSurl;
    
    /**
     * ReasonClass Property
     */
    Error::Category reasonClass;

    /**
     * Reason Property
     */
    std::string reason;
    
    /**
     * Failures Property
     */
    unsigned int failures;
    
    /**
     * Current Failures Property (reset at the Hold->Pending transition)
     */
    unsigned int currentFailures;
    
    /**
     * File Size Property
     */
    longlong fileSize;

    /**
     * Checksum Property
     */
    std::string checksum;
    
    /**
     * Finish Time Property
     */
    time_t finishTime;

    /**
     * Agent DN Property
     */
    std::string agentDn;
};

} // End namespace model
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_MODEL_FILE_H_
