/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: Job Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Job.h,v 1.8.4.1 2006/03/14 16:58:23 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_MODEL_JOB_H_
#define GLITE_DATA_TRANSFER_AGENTS_MODEL_JOB_H_

#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace model   {

/**
 * Job Class
 * @stereotype TransferObject
 */
struct Job {
    
    typedef enum{ // Define values so they could combined in OR
        S_UNDEF          = 0x0000,
        S_SUBMITTED      = 0x0001,
        S_PENDING        = S_SUBMITTED << 1,  //0x0002
        S_ACTIVE         = S_PENDING   << 1,  //0x0004
        S_CANCELING      = S_ACTIVE    << 1,  //0x0008
        S_HOLD           = S_CANCELING << 1,  //0x0010
        S_DONE           = S_HOLD      << 1,  //0x0020
        S_CANCELED       = S_DONE      << 1,  //0x0040
        S_FAILED         = S_CANCELED  << 1,  //0x0080
        S_FINISHED       = S_FAILED    << 1,  //0x0100
        S_FINISHED_DIRTY = S_FINISHED  << 1   //0x0200
    } State;

    /**
     * Job Default Priority
     */
    static const unsigned int DEFAULT_PRIORITY = 3;
   
    /**
     * Default Constructor
     */
    Job():priority(DEFAULT_PRIORITY),submitTime((time_t)-1),maxTimeInQueue(0){}

    /**
     * Constructor
     */
    Job(const std::string& i,               // job_id
              State        s,               // state
        const std::string& vname,           // vo_name
        const std::string& ch = "",         // channel_name
              unsigned int pr = DEFAULT_PRIORITY,// priority
        const std::string& src = "",        // source
        const std::string& dst = "",        // dest
        const std::string& u_dn = "",       // user_dn
        const std::string& v_crd = "",      // voms_cred
        const std::string& p = "",          // job_params
        const std::string& r = "",          // reason
              time_t       t = (time_t)-1,  // submit_time
        const std::string& a_dn  = "",      // agent_dn
        const std::string& sh    = "",      // submit_host
              unsigned int mtiq  = 0,       // max_time_in_queue
        const std::string& u_crd = "",      // user_cred
        const std::string& i_p   = ""):     // internal_params
         id(i),state(s),voName(vname),channelName(ch),priority(pr),
         source(src),dest(dst),userDn(u_dn),userCred(u_crd),
         vomsCred(v_crd),params(p),reason(r),submitTime(t),
         submitHost(sh),maxTimeInQueue(mtiq),agentDn(a_dn),internalParams(i_p){}

    /**
     * Id Property
     */
    std::string const id;

    /**
     * State Property
     */
    State state;

    /**
     * VO Name Property
     */
    std::string const voName;

    /**
     * Channel Property
     */
    std::string channelName;

    /**
     * Priority Property
     */
    unsigned int const priority;

    /**
     * Source Property
     */
    std::string source;

    /**
     * Dest Property
     */
    std::string dest; 

    /**
     * User Dn Property
     */
    std::string const userDn;

    /**
     * User Cred Property
     */
    std::string const userCred;
    
    /**
     * VOMS Cred Property
     */
    std::string const vomsCred;
    
    /**
     * Job Params Property
     */
    std::string const params;
    
    /**
     * Reason Property
     */
    std::string reason;
    
    /**
     * Submit Time Property
     */
    time_t const submitTime;

    /**
     * Submit Host Property
     */
    std::string const submitHost;
    
    /**
     * MaxTimeInQueue Property
     */
    unsigned int const maxTimeInQueue;

    /**
     * Agent DN Property
     */
    std::string agentDn;
    
    /**
     * Job Internal Params Property
     */
    std::string internalParams;
};

} // End namespace model
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_MODEL_JOB_H_
