/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: Transfer Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Transfer.h,v 1.5 2005/10/20 13:56:05 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_MODEL_TRANSFER_H_
#define GLITE_DATA_TRANSFER_AGENTS_MODEL_TRANSFER_H_

#include "glite/data/transfer/agent/glite-types.h"
#include "glite/data/transfer/agent/model/Error.h"
#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace model   {
    
/**
 * Transfer Class
 * @stereotype ValueObject
 */
struct Transfer {

    typedef enum{ // Define values so they could combined in OR
        S_UNDEF           = 0x0000,
        S_RECEIVED        = 0x0001,
        S_PROCESSING      = S_RECEIVED       << 1,  //0x0002
        S_COMPLETED       = S_PROCESSING     << 1,  //0x0004
        S_FAILED          = S_COMPLETED      << 1,  //0x0008
        S_ABORTED         = S_FAILED         << 1   //0x0010
    } State;

    /**
     * Default Constructor
     */
    Transfer():transferId(0),
               state(S_UNDEF),
               transferTime((time_t)-1),duration(0.0),bytesWritten(-1),
               reasonClass(Error::UNDEF),fileSize(0){}
                     
    /**
     * Constructor
     */
    Transfer(const std::string& req_id,               // request_id
             const std::string& file_id,              // file_id
                   unsigned int t_id,                 // transfer_id
                   State        s,                    // state
             const std::string& sturl = "",           // source_turl
             const std::string& dturl = "",           // dest_turl
                   time_t t           = (time_t)-1,   // transfer_time
                   double d           = 0.0,          // duration
                   longlong bw        = -1,           // bytes_written
                   Error::Category rc = Error::UNDEF, // reason_class
             const std::string& r     = "",           // reason
                   longlong fs        = 0):           // file_size
                 requestId(req_id),fileId(file_id),transferId(t_id),
                 state(s),sourceTurl(sturl),destTurl(dturl),
                 transferTime(t),duration(d),bytesWritten(bw),
                 reasonClass(rc),reason(r),fileSize(fs){}

    /**
     * RequestId Property
     */
    std::string const requestId;

    /**
     * FileId Property
     */
    std::string const fileId;

    /**
     * TransferId Property
     */
    unsigned int const transferId;

    /**
     * State Property
     */
    State state;

    /**
     * Source TURL Property
     */
    std::string sourceTurl;

    /**
     * Dest TURL Property
     */
    std::string destTurl;

    /**
     * Transfer Time Property
     */
    time_t transferTime;

    /**
     * Transfer Duration Property
     */
    double duration;

    /**
     * Bytes Written Property
     */
    longlong bytesWritten;
    
    /**
     * ReasonClass Property
     */
    Error::Category reasonClass;

    /**
     * Reason Property
     */
    std::string reason;

    /**
     * File Size Property
     */
    longlong fileSize;
};

} // End namespace model
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_MODEL_TRANSFER_H_
