/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: TransferException Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: TransferException.h,v 1.1 2005/05/31 16:53:47 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_TRANSFEREXCEPTION_H_
#define GLITE_DATA_TRANSFER_AGENTS_TRANSFEREXCEPTION_H_

#include "glite/data/transfer/agent/AgentException.h"
#include "glite/data/transfer/agent/model/Error.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace ts      {
    
/**
 * The TransferException is thrown when an error happens contacting the
 * FileTransfer Sevrice
 */
class TransferException : public AgentException {
public:

    /**
     * Error Category Type
     */
    typedef enum {
        TRANSFER_ERROR  = 0,
        AGENT_ERROR,
        SECURITY_ERROR,
        ORIG_ERROR, 
        DEST_ERROR
    } ErrorCategory;

    /**
     * Constructor
     * @param c [IN] the error Category
     * @param reason [IN] the reason of the error
     */
    TransferException(glite::data::transfer::agent::model::Error::Category c, 
        const char * reason):AgentException(reason),m_category(c){}

    /**
     * Destructor
     */
    virtual ~TransferException() throw() {}
    
    /**
     * Get Error Category Property
     */
    glite::data::transfer::agent::model::Error::Category category() const {return m_category;};
        
private:

    /**
     * Default Constructor Not Implemented
     */
    TransferException();
private:
    
    /**
     * Error Category Property
     */
    glite::data::transfer::agent::model::Error::Category m_category;
};

} // End namespace ts
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_TRANSFEREXCEPTION_H_
