/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: TransferServiceFactory Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: TransferServiceFactory.h,v 1.1 2005/05/31 16:53:47 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_2_2_4 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_TS_TRANSFERSERVICEFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_TS_TRANSFERSERVICEFACTORY_H_

#include "glite/data/transfer/agent/ts/TransferException.h"
#include "glite/data/transfer/agent/ts/TransferService.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace ts      {

/**
 * TransferServiceFactory interface
 * @interface
 */
class TransferServiceFactory  {
public:

    /**
     * Create a TransferService Proxy for the given channel
     * @param channel_name [IN] the name of the channel the TransferService is
     * responsible for
     * @return a new instance of a TransferService
     * @throws TransferException in case of error
     */
    virtual TransferService * create(const std::string& channel_name) /*throw (TransferException)*/ = 0; 

    /**
     * Return the configured TransferServiceFactory Instance. Please note that 
     * this method doesn't allocate the instance (It's not a singleton)
     * @return the configued TransferServiceFactory 
     * @throws TransferException in case of no TransferServiceFactory is
     * configured
     */
    static TransferServiceFactory * getInstance() /*throw (TransferException)*/; 
   
protected:

    /**
     * Constructor
     */ 
    TransferServiceFactory();

    /**
     * Destructor
     */ 
    virtual ~TransferServiceFactory();

private:

    /**
     * The registered Instance
     */
    static TransferServiceFactory * s_instance;
    
    /** @link dependency 
     * @label creates*/
    /*# TransferService lnkTransferSevrice; */

    /** @link dependency 
     * @label throws*/
    /*# TransferException lnkTransferException; */
};

} // End namespace ts
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_TS_TRANSFERSERVICEFACTORY_H_
